% Filtros para la reconstriccion AP. Válido para ENO.
%  a=capiamincvpcoef(nl,nr,grau)
%  Entradas:
%           nl       = numero de nodos del stencil a la izquierda de x^{k}_{2i-1}
%           nr       = numero de nodos del stencil a la derecha de x^{k}_{2i-1}
%           grau     = grado del polinomio AP
%  Salidas
%           a=Coeficientes buscados (también se muestra por pantalla)
%
% Autor: José Jaime Noguera  +INFO: www.uv.es/anims/noguera

function a=capiamincvpcoef(nl,nr,grau)

A=capiamatriumincvp(nl,nr,grau);
C=(A'*A)^(-1)*A';

for i=1:grau+1
    coef(i)=1/2^(i-1);
end    

a=coef(1:grau+1)*C;
format rational
  a
format
sprintf('Comienza en f^{k-1}_{i+(%d)} y acaba en f^{k-1}_(i+(%d))',-nl,nr-1)